@@ -3,8 +3,8 @@ from bitmovin_api_sdk.models import EncodingMode
 
 
 class EncodingListQueryParams(object):
-    def __init__(self, offset=None, limit=None, sort=None, type_=None, status=None, cloud_region=None, selected_cloud_region=None, encoder_version=None, selected_encoder_version=None, selected_encoding_mode=None, name=None, search=None):
-        # type: (int, int, string_types, string_types, string_types, CloudRegion, CloudRegion, string_types, string_types, EncodingMode, string_types, string_types) -> None
+    def __init__(self, offset=None, limit=None, sort=None, type_=None, status=None, cloud_region=None, selected_cloud_region=None, encoder_version=None, selected_encoder_version=None, selected_encoding_mode=None, name=None, search=None, created_at_newer_than=None, created_at_older_than=None, started_at_newer_than=None, started_at_older_than=None):
+        # type: (int, int, string_types, string_types, string_types, CloudRegion, CloudRegion, string_types, string_types, EncodingMode, string_types, string_types, datetime, datetime, datetime, datetime) -> None
         super(EncodingListQueryParams, self).__init__()
 
         self.offset = offset
@@ -19,6 +19,10 @@ class EncodingListQueryParams(object):
         self.selected_encoding_mode = selected_encoding_mode
         self.name = name
         self.search = search
+        self.created_at_newer_than = created_at_newer_than
+        self.created_at_older_than = created_at_older_than
+        self.started_at_newer_than = started_at_newer_than
+        self.started_at_older_than = started_at_older_than
 
     @property
     def openapi_types(self):
@@ -34,7 +38,11 @@ class EncodingListQueryParams(object):
             'selected_encoder_version': 'string_types',
             'selected_encoding_mode': 'EncodingMode',
             'name': 'string_types',
-            'search': 'string_types'
+            'search': 'string_types',
+            'created_at_newer_than': 'datetime',
+            'created_at_older_than': 'datetime',
+            'started_at_newer_than': 'datetime',
+            'started_at_older_than': 'datetime'
         }
 
         return types
@@ -53,7 +61,11 @@ class EncodingListQueryParams(object):
             'selected_encoder_version': 'selectedEncoderVersion',
             'selected_encoding_mode': 'selectedEncodingMode',
             'name': 'name',
-            'search': 'search'
+            'search': 'search',
+            'created_at_newer_than': 'createdAtNewerThan',
+            'created_at_older_than': 'createdAtOlderThan',
+            'started_at_newer_than': 'startedAtNewerThan',
+            'started_at_older_than': 'startedAtOlderThan'
         }
 
         return attributes
