@@ -48,6 +48,9 @@ from bitmovin_api_sdk.models.akamai_msl_version import AkamaiMslVersion
 from bitmovin_api_sdk.models.akamai_net_storage_input import AkamaiNetStorageInput
 from bitmovin_api_sdk.models.akamai_net_storage_output import AkamaiNetStorageOutput
 from bitmovin_api_sdk.models.analytics_abstract_filter import AnalyticsAbstractFilter
+from bitmovin_api_sdk.models.analytics_alerting_notification import AnalyticsAlertingNotification
+from bitmovin_api_sdk.models.analytics_alerting_rule import AnalyticsAlertingRule
+from bitmovin_api_sdk.models.analytics_alerting_webhook import AnalyticsAlertingWebhook
 from bitmovin_api_sdk.models.analytics_attribute import AnalyticsAttribute
 from bitmovin_api_sdk.models.analytics_avg_concurrent_viewers_response import AnalyticsAvgConcurrentViewersResponse
 from bitmovin_api_sdk.models.analytics_avg_dropped_frames_response import AnalyticsAvgDroppedFramesResponse
@@ -67,6 +70,7 @@ from bitmovin_api_sdk.models.analytics_impression_list_item import AnalyticsImpr
 from bitmovin_api_sdk.models.analytics_impressions_query import AnalyticsImpressionsQuery
 from bitmovin_api_sdk.models.analytics_impressions_response import AnalyticsImpressionsResponse
 from bitmovin_api_sdk.models.analytics_in_filter import AnalyticsInFilter
+from bitmovin_api_sdk.models.analytics_incident import AnalyticsIncident
 from bitmovin_api_sdk.models.analytics_insights_organization_settings import AnalyticsInsightsOrganizationSettings
 from bitmovin_api_sdk.models.analytics_insights_organization_settings_request import AnalyticsInsightsOrganizationSettingsRequest
 from bitmovin_api_sdk.models.analytics_interval import AnalyticsInterval
@@ -91,8 +95,10 @@ from bitmovin_api_sdk.models.analytics_query_operator import AnalyticsQueryOpera
 from bitmovin_api_sdk.models.analytics_query_request import AnalyticsQueryRequest
 from bitmovin_api_sdk.models.analytics_query_timeframe import AnalyticsQueryTimeframe
 from bitmovin_api_sdk.models.analytics_response import AnalyticsResponse
+from bitmovin_api_sdk.models.analytics_rule_metric import AnalyticsRuleMetric
 from bitmovin_api_sdk.models.analytics_stddev_query_request import AnalyticsStddevQueryRequest
 from bitmovin_api_sdk.models.analytics_sum_query_request import AnalyticsSumQueryRequest
+from bitmovin_api_sdk.models.analytics_threshold_rule_options import AnalyticsThresholdRuleOptions
 from bitmovin_api_sdk.models.analytics_variance_query_request import AnalyticsVarianceQueryRequest
 from bitmovin_api_sdk.models.analytics_video_start_failed_reason import AnalyticsVideoStartFailedReason
 from bitmovin_api_sdk.models.and_conjunction import AndConjunction
@@ -165,6 +171,7 @@ from bitmovin_api_sdk.models.cenc_marlin import CencMarlin
 from bitmovin_api_sdk.models.cenc_play_ready import CencPlayReady
 from bitmovin_api_sdk.models.cenc_widevine import CencWidevine
 from bitmovin_api_sdk.models.channel_layout import ChannelLayout
+from bitmovin_api_sdk.models.channels_attribute_for_audio import ChannelsAttributeForAudio
 from bitmovin_api_sdk.models.chroma_location import ChromaLocation
 from bitmovin_api_sdk.models.chunked_text_muxing import ChunkedTextMuxing
 from bitmovin_api_sdk.models.clear_key_drm import ClearKeyDrm
@@ -270,7 +277,6 @@ from bitmovin_api_sdk.models.encoding_stream_input import EncodingStreamInput
 from bitmovin_api_sdk.models.encoding_stream_input_details import EncodingStreamInputDetails
 from bitmovin_api_sdk.models.encoding_type import EncodingType
 from bitmovin_api_sdk.models.encryption_mode import EncryptionMode
-from bitmovin_api_sdk.models.encryption_type import EncryptionType
 from bitmovin_api_sdk.models.enhanced_deinterlace_auto_enable import EnhancedDeinterlaceAutoEnable
 from bitmovin_api_sdk.models.enhanced_deinterlace_filter import EnhancedDeinterlaceFilter
 from bitmovin_api_sdk.models.enhanced_deinterlace_mode import EnhancedDeinterlaceMode
@@ -278,6 +284,7 @@ from bitmovin_api_sdk.models.enhanced_deinterlace_parity import EnhancedDeinterl
 from bitmovin_api_sdk.models.enhanced_watermark_filter import EnhancedWatermarkFilter
 from bitmovin_api_sdk.models.error_details import ErrorDetails
 from bitmovin_api_sdk.models.error_retry_hint import ErrorRetryHint
+from bitmovin_api_sdk.models.external_id_mode import ExternalIdMode
 from bitmovin_api_sdk.models.fair_play_drm import FairPlayDrm
 from bitmovin_api_sdk.models.file_input_stream import FileInputStream
 from bitmovin_api_sdk.models.file_input_stream_type import FileInputStreamType
@@ -451,6 +458,11 @@ from bitmovin_api_sdk.models.position_mode import PositionMode
 from bitmovin_api_sdk.models.position_unit import PositionUnit
 from bitmovin_api_sdk.models.preset_configuration import PresetConfiguration
 from bitmovin_api_sdk.models.prewarm_encoder_settings import PrewarmEncoderSettings
+from bitmovin_api_sdk.models.prewarmed_encoder_disk_size import PrewarmedEncoderDiskSize
+from bitmovin_api_sdk.models.prewarmed_encoder_pool import PrewarmedEncoderPool
+from bitmovin_api_sdk.models.prewarmed_encoder_pool_action import PrewarmedEncoderPoolAction
+from bitmovin_api_sdk.models.prewarmed_encoder_pool_schedule import PrewarmedEncoderPoolSchedule
+from bitmovin_api_sdk.models.prewarmed_encoder_pool_status import PrewarmedEncoderPoolStatus
 from bitmovin_api_sdk.models.prime_time_drm import PrimeTimeDrm
 from bitmovin_api_sdk.models.profile_h262 import ProfileH262
 from bitmovin_api_sdk.models.profile_h264 import ProfileH264
@@ -608,8 +620,10 @@ from bitmovin_api_sdk.models.web_vtt_configuration import WebVttConfiguration
 from bitmovin_api_sdk.models.web_vtt_sidecar_file import WebVttSidecarFile
 from bitmovin_api_sdk.models.web_vtt_sidecar_file_segmentation import WebVttSidecarFileSegmentation
 from bitmovin_api_sdk.models.webhook import Webhook
-from bitmovin_api_sdk.models.webhook_encryption import WebhookEncryption
 from bitmovin_api_sdk.models.webhook_http_method import WebhookHttpMethod
+from bitmovin_api_sdk.models.webhook_notification import WebhookNotification
+from bitmovin_api_sdk.models.webhook_notification_with_stream_conditions import WebhookNotificationWithStreamConditions
+from bitmovin_api_sdk.models.webhook_notification_with_stream_conditions_request import WebhookNotificationWithStreamConditionsRequest
 from bitmovin_api_sdk.models.webhook_signature import WebhookSignature
 from bitmovin_api_sdk.models.webm_muxing import WebmMuxing
 from bitmovin_api_sdk.models.weighted_prediction_p_frames import WeightedPredictionPFrames
