@@ -7,6 +7,7 @@ from bitmovin_api_sdk.common.poscheck import poscheck_except
 from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.finished.finished_api import FinishedApi
 from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.error.error_api import ErrorApi
 from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.transfer_error.transfer_error_api import TransferErrorApi
+from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.live_input_stream_changed.live_input_stream_changed_api import LiveInputStreamChangedApi
 
 
 class EncodingsApi(BaseApi):
@@ -41,3 +42,10 @@ class EncodingsApi(BaseApi):
             base_url=base_url,
             logger=logger
         )
+
+        self.live_input_stream_changed = LiveInputStreamChangedApi(
+            api_key=api_key,
+            tenant_org_id=tenant_org_id,
+            base_url=base_url,
+            logger=logger
+        )
